# Applying and exposing the photoresist dry film

[[Home|/home]] ► [[Electronics|/electronics]] ► [[Circuit board fabrication|/electronics/pcbfabrication]] ► Applying and exposing the photoresist dry film

___

**Prerequisites**

* [Copper layer printed on a transparency](/electronics/electronics/pcbfabrication/transparencies)
* [Laminator](/electronics/bom#hardware_laminator)
* [Circuit board](/electronics/bom#consumables_circuit-board)
* [Photosensitive film](/electronics/bom#consumables_photosensitive-film)
* [UV light source](/electronics/bom#hardware_uv-light-source)
* [Microscope](/electronics/bom#hardware_microscope)
* [4.8% sodium metasilicate](/electronics/bom#chemicals_sodium-metasilicate)
* Glass plate
* Tape
* Squeegee / card
* Water
* Cardboard
* Leftover transparency or a piece of paper
* Gloves

[[_TOC_]]

I hope to extend these instructions with photos and/or videos some day. For now I'll just post my notes.

The basis for these steps have been taken from this video, which I recommend watching: [[https://www.youtube.com/watch?v=cRCFGZxmob0]]

## Applying the film
1. Cut the copper board. Don't cut it to the final dimensions just yet, leave a bit of room for the film.
1. Clean the copper board. Use soap to clean off dirt and grease, then scrub it with a scrub sponge. This cleans up the copper and increases adhesion for the film.
1. Wet the copper board with water. I found that a small face mist device sold on eBay and AliExpress works very well to deposit a consistent but thin layer, but a simple sprayer or squeeze bottle will also work.
1. Preheat the laminator to around 120 degrees Celcius.
1. Close the curtains, you don't want sunlight on your UV sensitive film. Lights are fine, especially LED lighting should output very little UV.
1. Cut a piece of the photosensitive film to size. You want to end up with roughly the same size as the copper board, maybe even slightly smaller, but enough to cover the whole circuit design.
1. Remove one of the outer protective layers of the film. The easiest way to do this is to take two pieces of tape, attaching them to a corner on either side of the film and pulling them apart. One of the layers will pull away.
1. Apply the film to the copper board with the side where you just removed the protective layer. Use a squeegee or card to remove any bubbles.
1. Put the board on a piece of cardboard and cover it with a spare piece of transparency or paper. The extra layer prevents wrinkling and the carboard helps guide the board through the laminator especially on smaller boards.
1. Take the board through the laminator two or three times at a 45 degree angle. This way the rollers pick up a small piece of the board to begin with, and it is less likely to jam. Adjust the spring tension on the rollers if you're having issues.

## Exposing
1. Leave the second protective layer on the film for now, this prevents the transparency from sticking to the film and making it reusable.
1. Put the transparency on the board and film with the printed side facing down.
1. Put a glass plate on top to keep everything pressed together and place it under the UV light source.
1. Expose the board. You'll want to experiment a bit, with my UV box I run it for **45 seconds on 50%**.
1. Remove the second protective layer with another piece of tape. Be careful not to tear off the film along with it, start in a corner and if you see the thin layer coming off you can continue.

If you're doing a double-sided board (I haven't yet) you'll probably want to expose both sides at the same time or at least one after the other before developing the film. That way you can develop both sides at the same time and not have one side be in the developer twice as long potentially ruining the resist.

## Developing
Put the exposed board in the sodium metasilicate solution. Keep the liquid in motion to help the process. After a minute or two you can help along with a brush (I use a cheap toothbrush). Don't be afraid to scrub, if the film is gonna come off at this point it could also come off during etching so that'd be a good sign to start over.

If you're gonna be picking up the board to scrub it, use gloves. I'm not sure how harmful this solution is, but it's better to be safe than sorry!

You should see the unexposed areas dissolving. Rotate the board and use the reflection on the exposed copper to see if all the tracks and pads are separated where they should be, then rinse off with water.

## Checking the results
Check your board under a microscope. Anywhere there is bare copper will be etched away. Make sure tracks and pads have the designed clearance around them.

It is not uncommon to find bits of undissolved film remaining. You can do small corrections with a knife. If there is too much film to cut away, you could try putting it back in the developer a bit longer. If that doesn't help, or if the film has become loose in places where you don't want it to, it's probably best to start over. The good news is that this is relatively easy to do at this point:

1. Skip the etching step for now
1. [Remove the photoresist film](/electronics/electronics/pcbfabrication/removephotoresist)
1. Tweak any settings (exposure time and/or intensity) if necessary
1. Start over by cleaning the board and applying new film